var geodashboardRoot = require('system').env['PWD'];
var app = require(geodashboardRoot + '/app.json');

casper.test.begin('Geodashboard Home page', 125, function suite(test) {

    var url, screenshotRoot, modules, phantomCSS, page, appObject;

    url             = "http://localhost:9000";
    screenshotRoot  = 'results/screenshots';
    modules         = geodashboardRoot + '/node_modules';
    phantomCSS      = require(modules + '/phantomcss/phantomcss.js');
    page            = { width: 1024, height: 768 };

    phantomCSS.init({
      screenshotRoot: screenshotRoot,
      failedComparisonsRoot: screenshotRoot + '/failures',
      libraryRoot: modules + '/phantomcss',
      cleanupComparisonImages: true,
      comparisonResultRoot: screenshotRoot + '/results'
    });

    casper.start(url);
    casper.viewport(page.width, page.height);

    casper.options.waitTimeout = 15000; // set a 15 second timeout

    casper.waitFor(function inspectTrendsView() {
        return this.evaluate(function() {
            return document.querySelector('#dashboard');
        });
    }, function then() {

        // Explore Sources - Sensor Pills
        appObject = this.page.evaluate(function() {
            return window.app;
        });

        test.assertExists('a[href="#explore"]', "Explore nav button exists");

        if (appObject.config.views.about && appObject.config.views.about.title && appObject.config.views.about.link) {
            test.assertExists('a[href="#about"]', "About nav button exists");
        }
        if (appObject.config.views.compare && appObject.config.views.compare.title && appObject.config.views.compare.link) {
            test.assertExists('a[href="#compare"]', "Compare nav button exists");
        }
        if (appObject.config.views.search && appObject.config.views.search.title && appObject.config.views.search.link) {
            test.assertExists('a[href="#search"]', "Search nav button exists");
        }
        test.assertExists('#explore-map-view', "The map is found");
        phantomCSS.screenshot('#explore-map-view', 'explore-map-trends');
    });

    casper.then(function clickExploreSources() {
        // you can click an item by its css selector, or by it's label (if available)
        //this.click('a[href="#accordion-nav-collapse-sources"]');
        this.clickLabel('Explore Data by Source');

    });

    casper.waitFor(function inspectHomeView() {
        return this.evaluate(function() {
            return document.querySelectorAll('#explore-sources-accordion-contents');
        });
    }, function then() {
        test.assertTitle(app.title, "The title shows " + app.title);
        test.assertExists('#explore-sources-accordion-contents', "The explore sources container is found");
        test.assertExists('#explore-map-view', "The map is found");
        phantomCSS.screenshot('#explore-map-view', 'explore-map-sources');

        // Explore Sources - Sensor Pills
        var sensors = this.page.evaluate(function() {
            return window.app.collection.sensors.toJSON();
        });

        for (var i = 0; i < sensors.length; i++) {
            var name = sensors[i].properties.name;
            test.assertExists('button[title="' + name + '"]', "The pill for " + name + " was found.");
        }

        // Explore Sources - Source Titles
        var sources = this.page.evaluate(function() {
            return window.app.collection.sources.toJSON();
        });

        for (var j = 0; j < sources.length; j++) {
            var sourceTitle = sources[j].prettyName;
            test.assertSelectorHasText('a[href="#collapse-' + sources[j].id + '"] > span[class="data-nav2-text-title"]', sourceTitle);
        }

    });

//    bamboo won't compare screenshots since the screenshots folder is empty on each new build
//    uncomment this if you want to compare screenshots
//    casper.then( function now_check_the_screenshots(){
//      // compare screenshots
//      phantomCSS.compareAll();
//    });

    /*
     Casper runs tests
     */
    casper.run(function(){
      test.done();
      console.log('\nTHE END.');
      phantom.exit(phantomCSS.getExitStatus());
    });
});
